summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--svl/inc/svl/cntnrsrt.hxx24
-rw-r--r--svl/inc/svl/filerec.hxx2
-rw-r--r--svl/inc/svl/instrm.hxx14
-rw-r--r--svl/inc/svl/itempool.hxx12
-rw-r--r--svl/inc/svl/nranges.hxx2
-rw-r--r--svl/inc/svl/outstrm.hxx8
-rw-r--r--svl/inc/svl/poolitem.hxx16
-rw-r--r--svl/inc/svl/rngitem.hxx2
-rw-r--r--svl/inc/svl/smplhint.hxx6
-rw-r--r--svl/inc/svl/strmadpt.hxx16
-rw-r--r--svl/inc/svl/style.hxx6
-rw-r--r--svl/inc/svl/svdde.hxx30
-rw-r--r--svl/inc/svl/svstdarr.hxx4
-rw-r--r--svl/inc/svl/zformat.hxx4
-rw-r--r--svl/source/inc/passwordcontainer.hxx6
-rw-r--r--svl/source/items/itemset.cxx10
-rw-r--r--svl/source/items/lckbitem.cxx6
-rw-r--r--svl/source/items/poolio.cxx30
-rw-r--r--svl/source/items/poolitem.cxx4
-rw-r--r--svl/source/items/slstitm.cxx4
-rw-r--r--svl/source/items/style.cxx12
-rw-r--r--svl/source/memtools/svarray.cxx4
-rw-r--r--svl/source/misc/adrparse.cxx2
-rw-r--r--svl/source/misc/inettype.cxx2
-rw-r--r--svl/source/misc/ownlist.cxx2
-rw-r--r--svl/source/misc/strmadpt.cxx56
-rw-r--r--svl/source/notify/smplhint.cxx2
-rw-r--r--svl/source/numbers/numfmuno.cxx2
-rw-r--r--svl/source/numbers/numfmuno.hxx4
-rw-r--r--svl/source/numbers/numhead.cxx32
-rw-r--r--svl/source/numbers/numhead.hxx22
-rw-r--r--svl/source/numbers/zforlist.cxx4
-rw-r--r--svl/source/numbers/zformat.cxx50
-rw-r--r--svl/source/svdde/ddecli.cxx4
-rw-r--r--svl/source/svdde/ddedata.cxx12
-rw-r--r--svl/source/svdde/ddeimp.hxx10
-rw-r--r--svl/source/svdde/ddesvr.cxx20
-rw-r--r--svl/unx/source/svdde/ddedummy.cxx12
38 files changed, 229 insertions, 229 deletions
diff --git a/svl/inc/svl/cntnrsrt.hxx b/svl/inc/svl/cntnrsrt.hxx
index f7c114274981..7c0dc6863371 100644
--- a/svl/inc/svl/cntnrsrt.hxx
+++ b/svl/inc/svl/cntnrsrt.hxx
@@ -68,12 +68,12 @@ public: \
\
sal_Bool Insert( Type* pObj ); \
\
- Type *Remove( sal_uIntPtr nPos ) \
+ Type *Remove( sal_uLong nPos ) \
{ return (Type *)Container::Remove( nPos ); } \
\
Type *Remove( Type* pObj ); \
\
- void DeleteAndDestroy( sal_uIntPtr nPos ) \
+ void DeleteAndDestroy( sal_uLong nPos ) \
{ \
Type *pObj = Remove( nPos ); \
if( pObj ) \
@@ -83,15 +83,15 @@ public: \
void DeleteAndDestroy() \
{ while( Count() ) DeleteAndDestroy( 0 ); } \
\
- Type* GetObject( sal_uIntPtr nPos ) const \
+ Type* GetObject( sal_uLong nPos ) const \
{ return (Type *)Container::GetObject( nPos ); } \
\
- Type* operator[]( sal_uIntPtr nPos ) const \
+ Type* operator[]( sal_uLong nPos ) const \
{ return GetObject(nPos); } \
\
- sal_Bool Seek_Entry( const Type *pObj, sal_uIntPtr* pPos ) const; \
+ sal_Bool Seek_Entry( const Type *pObj, sal_uLong* pPos ) const; \
\
- sal_uIntPtr GetPos( const Type* pObj ) const; \
+ sal_uLong GetPos( const Type* pObj ) const; \
#define DECLARE_CONTAINER_SORT( ClassName, Type ) \
@@ -113,7 +113,7 @@ class ClassName : private Container \
#define IMPL_CONTAINER_SORT( ClassName, Type, SortFunc ) \
sal_Bool ClassName::Insert( Type *pObj ) \
{ \
- sal_uIntPtr nPos; \
+ sal_uLong nPos; \
sal_Bool bExist = Seek_Entry( pObj, &nPos ); \
if( !bExist ) \
Container::Insert( pObj, nPos ); \
@@ -122,25 +122,25 @@ sal_Bool ClassName::Insert( Type *pObj )
\
Type *ClassName::Remove( Type* pObj ) \
{ \
- sal_uIntPtr nPos; \
+ sal_uLong nPos; \
if( Seek_Entry( pObj, &nPos ) ) \
return Remove( nPos ); \
else \
return 0; \
} \
\
-sal_uIntPtr ClassName::GetPos( const Type* pObj ) const \
+sal_uLong ClassName::GetPos( const Type* pObj ) const \
{ \
- sal_uIntPtr nPos; \
+ sal_uLong nPos; \
if( Seek_Entry( pObj, &nPos ) ) \
return nPos; \
else \
return CONTAINER_ENTRY_NOTFOUND; \
} \
\
-sal_Bool ClassName::Seek_Entry( const Type* pObj, sal_uIntPtr* pPos ) const \
+sal_Bool ClassName::Seek_Entry( const Type* pObj, sal_uLong* pPos ) const \
{ \
- register sal_uIntPtr nO = Count(), \
+ register sal_uLong nO = Count(), \
nM, \
nU = 0; \
if( nO > 0 ) \
diff --git a/svl/inc/svl/filerec.hxx b/svl/inc/svl/filerec.hxx
index 0a831023f3ff..eef347ab772b 100644
--- a/svl/inc/svl/filerec.hxx
+++ b/svl/inc/svl/filerec.hxx
@@ -973,7 +973,7 @@ inline void SfxMultiFixRecordWriter::NewContent()
{
#ifdef DBG_UTIL
- sal_uIntPtr nOldStartPos;
+ sal_uLong nOldStartPos;
// Startposition des aktuellen Contents merken - Achtung Subklassen!
nOldStartPos = _nContentStartPos;
#endif
diff --git a/svl/inc/svl/instrm.hxx b/svl/inc/svl/instrm.hxx
index f27375baff25..124c80a21630 100644
--- a/svl/inc/svl/instrm.hxx
+++ b/svl/inc/svl/instrm.hxx
@@ -47,19 +47,19 @@ class SVL_DLLPUBLIC SvInputStream: public SvStream
com::sun::star::uno::Reference< com::sun::star::io::XSeekable >
m_xSeekable;
SvDataPipe_Impl * m_pPipe;
- sal_uIntPtr m_nSeekedFrom;
+ sal_uLong m_nSeekedFrom;
SVL_DLLPRIVATE bool open();
- SVL_DLLPRIVATE virtual sal_uIntPtr GetData(void * pData, sal_uIntPtr nSize);
+ SVL_DLLPRIVATE virtual sal_uLong GetData(void * pData, sal_uLong nSize);
- SVL_DLLPRIVATE virtual sal_uIntPtr PutData(void const *, sal_uIntPtr);
+ SVL_DLLPRIVATE virtual sal_uLong PutData(void const *, sal_uLong);
- SVL_DLLPRIVATE virtual sal_uIntPtr SeekPos(sal_uIntPtr nPos);
+ SVL_DLLPRIVATE virtual sal_uLong SeekPos(sal_uLong nPos);
SVL_DLLPRIVATE virtual void FlushData();
- SVL_DLLPRIVATE virtual void SetSize(sal_uIntPtr);
+ SVL_DLLPRIVATE virtual void SetSize(sal_uLong);
public:
SvInputStream(
@@ -71,9 +71,9 @@ public:
virtual sal_uInt16 IsA() const;
- virtual void AddMark(sal_uIntPtr nPos);
+ virtual void AddMark(sal_uLong nPos);
- virtual void RemoveMark(sal_uIntPtr nPos);
+ virtual void RemoveMark(sal_uLong nPos);
};
#endif // SVTOOLS_INSTRM_HXX
diff --git a/svl/inc/svl/itempool.hxx b/svl/inc/svl/itempool.hxx
index 7f00f89bc9e2..735f9b1162aa 100644
--- a/svl/inc/svl/itempool.hxx
+++ b/svl/inc/svl/itempool.hxx
@@ -154,9 +154,9 @@ public:
//---------------------------------------------------------------------
protected:
- static inline void SetRefCount( SfxPoolItem& rItem, sal_uIntPtr n );
- static inline sal_uIntPtr AddRef( const SfxPoolItem& rItem, sal_uIntPtr n = 1 );
- static inline sal_uIntPtr ReleaseRef( const SfxPoolItem& rItem, sal_uIntPtr n = 1);
+ static inline void SetRefCount( SfxPoolItem& rItem, sal_uLong n );
+ static inline sal_uLong AddRef( const SfxPoolItem& rItem, sal_uLong n = 1 );
+ static inline sal_uLong ReleaseRef( const SfxPoolItem& rItem, sal_uLong n = 1);
public:
SfxItemPool( const SfxItemPool &rPool,
@@ -283,19 +283,19 @@ private:
// --------------- Inline Implementierungen ------------------------------
// nur der Pool darf den Referenz-Zaehler manipulieren !!!
-inline void SfxItemPool::SetRefCount( SfxPoolItem& rItem, sal_uIntPtr n )
+inline void SfxItemPool::SetRefCount( SfxPoolItem& rItem, sal_uLong n )
{
rItem.SetRefCount(n);
}
// nur der Pool darf den Referenz-Zaehler manipulieren !!!
-inline sal_uIntPtr SfxItemPool::AddRef( const SfxPoolItem& rItem, sal_uIntPtr n )
+inline sal_uLong SfxItemPool::AddRef( const SfxPoolItem& rItem, sal_uLong n )
{
return rItem.AddRef(n);
}
// nur der Pool darf den Referenz-Zaehler manipulieren !!!
-inline sal_uIntPtr SfxItemPool::ReleaseRef( const SfxPoolItem& rItem, sal_uIntPtr n )
+inline sal_uLong SfxItemPool::ReleaseRef( const SfxPoolItem& rItem, sal_uLong n )
{
return rItem.ReleaseRef(n);
}
diff --git a/svl/inc/svl/nranges.hxx b/svl/inc/svl/nranges.hxx
index 9571fc79cb47..c7ba2029f5a6 100644
--- a/svl/inc/svl/nranges.hxx
+++ b/svl/inc/svl/nranges.hxx
@@ -40,7 +40,7 @@
#include <svl/nranges.hxx>
#undef NUMTYPE
-#define NUMTYPE sal_uIntPtr
+#define NUMTYPE sal_uLong
#define SfxNumRanges SfxULongRanges
#include <svl/nranges.hxx>
diff --git a/svl/inc/svl/outstrm.hxx b/svl/inc/svl/outstrm.hxx
index 8846bd84e5df..b48cea2e04da 100644
--- a/svl/inc/svl/outstrm.hxx
+++ b/svl/inc/svl/outstrm.hxx
@@ -42,15 +42,15 @@ class SVL_DLLPUBLIC SvOutputStream: public SvStream
com::sun::star::uno::Reference< com::sun::star::io::XOutputStream >
m_xStream;
- SVL_DLLPRIVATE virtual sal_uIntPtr GetData(void *, sal_uIntPtr);
+ SVL_DLLPRIVATE virtual sal_uLong GetData(void *, sal_uLong);
- SVL_DLLPRIVATE virtual sal_uIntPtr PutData(void const * pData, sal_uIntPtr nSize);
+ SVL_DLLPRIVATE virtual sal_uLong PutData(void const * pData, sal_uLong nSize);
- SVL_DLLPRIVATE virtual sal_uIntPtr SeekPos(sal_uIntPtr);
+ SVL_DLLPRIVATE virtual sal_uLong SeekPos(sal_uLong);
SVL_DLLPRIVATE virtual void FlushData();
- SVL_DLLPRIVATE virtual void SetSize(sal_uIntPtr);
+ SVL_DLLPRIVATE virtual void SetSize(sal_uLong);
public:
SvOutputStream(com::sun::star::uno::Reference<
diff --git a/svl/inc/svl/poolitem.hxx b/svl/inc/svl/poolitem.hxx
index 0a8b63e1b155..48e5a80166b7 100644
--- a/svl/inc/svl/poolitem.hxx
+++ b/svl/inc/svl/poolitem.hxx
@@ -183,17 +183,17 @@ friend class SfxItemPoolCache;
friend class SfxItemSet;
friend class SfxVoidItem;
- sal_uIntPtr nRefCount; // Referenzzaehler
+ sal_uLong nRefCount; // Referenzzaehler
sal_uInt16 nWhich;
sal_uInt16 nKind;
private:
- inline void SetRefCount( sal_uIntPtr n );
+ inline void SetRefCount( sal_uLong n );
inline void SetKind( sal_uInt16 n );
public:
- inline sal_uIntPtr AddRef( sal_uIntPtr n = 1 ) const;
+ inline sal_uLong AddRef( sal_uLong n = 1 ) const;
private:
- inline sal_uIntPtr ReleaseRef( sal_uIntPtr n = 1 ) const;
+ inline sal_uLong ReleaseRef( sal_uLong n = 1 ) const;
SVL_DLLPRIVATE long Delete_Impl(void*);
#if 0
@@ -239,7 +239,7 @@ public:
virtual SvStream& Store( SvStream &, sal_uInt16 nItemVersion ) const;
virtual SfxPoolItem* Clone( SfxItemPool *pPool = 0 ) const = 0;
- sal_uIntPtr GetRefCount() const { return nRefCount; }
+ sal_uLong GetRefCount() const { return nRefCount; }
inline sal_uInt16 GetKind() const { return nKind; }
/** Read in a Unicode string from a streamed byte string representation.
@@ -295,7 +295,7 @@ private:
// -----------------------------------------------------------------------
-inline void SfxPoolItem::SetRefCount( sal_uIntPtr n )
+inline void SfxPoolItem::SetRefCount( sal_uLong n )
{
DBG_CHKTHIS( SfxPoolItem, 0 );
nRefCount = n;
@@ -309,7 +309,7 @@ inline void SfxPoolItem::SetKind( sal_uInt16 n )
nKind = n;
}
-inline sal_uIntPtr SfxPoolItem::AddRef( sal_uIntPtr n ) const
+inline sal_uLong SfxPoolItem::AddRef( sal_uLong n ) const
{
DBG_CHKTHIS( SfxPoolItem, 0 );
DBG_ASSERT( nRefCount <= SFX_ITEMS_MAXREF, "AddRef mit nicht-Pool-Item" );
@@ -317,7 +317,7 @@ inline sal_uIntPtr SfxPoolItem::AddRef( sal_uIntPtr n ) const
return ( ((SfxPoolItem *)this)->nRefCount += n );
}
-inline sal_uIntPtr SfxPoolItem::ReleaseRef( sal_uIntPtr n ) const
+inline sal_uLong SfxPoolItem::ReleaseRef( sal_uLong n ) const
{
DBG_CHKTHIS( SfxPoolItem, 0 );
DBG_ASSERT( nRefCount <= SFX_ITEMS_MAXREF, "AddRef mit nicht-Pool-Item" );
diff --git a/svl/inc/svl/rngitem.hxx b/svl/inc/svl/rngitem.hxx
index 914fb5f4cd9a..320c358f5520 100644
--- a/svl/inc/svl/rngitem.hxx
+++ b/svl/inc/svl/rngitem.hxx
@@ -38,7 +38,7 @@
#undef SfxXRangesItem
#ifndef _SFXITEMS_HXX
-#define NUMTYPE sal_uIntPtr
+#define NUMTYPE sal_uLong
#define SfxXRangeItem SfxULongRangeItem
#define SfxXRangesItem SfxULongRangesItem
#include <svl/rngitem.hxx>
diff --git a/svl/inc/svl/smplhint.hxx b/svl/inc/svl/smplhint.hxx
index 42e5aa4f69a4..9e3e867b1703 100644
--- a/svl/inc/svl/smplhint.hxx
+++ b/svl/inc/svl/smplhint.hxx
@@ -68,11 +68,11 @@
class SVL_DLLPUBLIC SfxSimpleHint: public SfxHint
{
private:
- sal_uIntPtr nId;
+ sal_uLong nId;
public:
TYPEINFO();
- SfxSimpleHint( sal_uIntPtr nId );
- sal_uIntPtr GetId() const { return nId; }
+ SfxSimpleHint( sal_uLong nId );
+ sal_uLong GetId() const { return nId; }
};
//--------------------------------------------------------------------
diff --git a/svl/inc/svl/strmadpt.hxx b/svl/inc/svl/strmadpt.hxx
index 0d2779504daf..936e33071706 100644
--- a/svl/inc/svl/strmadpt.hxx
+++ b/svl/inc/svl/strmadpt.hxx
@@ -51,23 +51,23 @@ public:
rTheOutputStream):
m_xOutputStream(rTheOutputStream), m_nPosition(0) {}
- virtual ErrCode ReadAt(sal_uIntPtr, void *, sal_uIntPtr, sal_uIntPtr *) const;
+ virtual ErrCode ReadAt(sal_uLong, void *, sal_uLong, sal_uLong *) const;
- virtual ErrCode WriteAt(sal_uIntPtr nPos, const void * pBuffer, sal_uIntPtr nCount,
- sal_uIntPtr * pWritten);
+ virtual ErrCode WriteAt(sal_uLong nPos, const void * pBuffer, sal_uLong nCount,
+ sal_uLong * pWritten);
virtual ErrCode Flush() const;
- virtual ErrCode SetSize(sal_uIntPtr);
+ virtual ErrCode SetSize(sal_uLong);
virtual ErrCode Stat(SvLockBytesStat * pStat, SvLockBytesStatFlag) const;
- virtual ErrCode FillAppend(const void * pBuffer, sal_uIntPtr nCount,
- sal_uIntPtr * pWritten);
+ virtual ErrCode FillAppend(const void * pBuffer, sal_uLong nCount,
+ sal_uLong * pWritten);
- virtual sal_uIntPtr Tell() const;
+ virtual sal_uLong Tell() const;
- virtual sal_uIntPtr Seek(sal_uIntPtr);
+ virtual sal_uLong Seek(sal_uLong);
virtual void Terminate();
};
diff --git a/svl/inc/svl/style.hxx b/svl/inc/svl/style.hxx
index 667fe7137994..5ae5cb8e673b 100644
--- a/svl/inc/svl/style.hxx
+++ b/svl/inc/svl/style.hxx
@@ -102,7 +102,7 @@ protected:
SfxItemSet* pSet; // ItemSet
sal_uInt16 nMask; // Flags
- sal_uIntPtr nHelpId; // Hilfe-ID
+ sal_uLong nHelpId; // Hilfe-ID
sal_Bool bMySet; // sal_True: Set loeschen im dtor
@@ -149,8 +149,8 @@ public:
sal_Bool IsUserDefined() const
{ return sal_Bool( ( nMask & SFXSTYLEBIT_USERDEF) != 0 ); }
- virtual sal_uIntPtr GetHelpId( String& rFile );
- virtual void SetHelpId( const String& r, sal_uIntPtr nId );
+ virtual sal_uLong GetHelpId( String& rFile );
+ virtual void SetHelpId( const String& r, sal_uLong nId );
virtual SfxItemSet& GetItemSet();
virtual sal_uInt16 GetVersion() const;
diff --git a/svl/inc/svl/svdde.hxx b/svl/inc/svl/svdde.hxx
index 229ecbec8361..35448521c459 100644
--- a/svl/inc/svl/svdde.hxx
+++ b/svl/inc/svl/svdde.hxx
@@ -92,11 +92,11 @@ class SVL_DLLPUBLIC DdeData
//#if 0 // _SOLAR__PRIVATE
SVL_DLLPRIVATE void Lock();
//#endif
- void SetFormat( sal_uIntPtr nFmt );
+ void SetFormat( sal_uLong nFmt );
public:
DdeData();
- DdeData( const void*, long, sal_uIntPtr = FORMAT_STRING );
+ DdeData( const void*, long, sal_uLong = FORMAT_STRING );
DdeData( const String& );
DdeData( const DdeData& );
~DdeData();
@@ -104,12 +104,12 @@ public:
operator const void*() const;
operator long() const;
- sal_uIntPtr GetFormat() const;
+ sal_uLong GetFormat() const;
DdeData& operator = ( const DdeData& );
- static sal_uIntPtr GetExternalFormat( sal_uIntPtr nFmt );
- static sal_uIntPtr GetInternalFormat( sal_uIntPtr nFmt );
+ static sal_uLong GetExternalFormat( sal_uLong nFmt );
+ static sal_uLong GetInternalFormat( sal_uLong nFmt );
};
// ------------------
// - DdeServiceList -
@@ -184,8 +184,8 @@ public:
void SetDoneHdl( const Link& rLink ) { aDone = rLink; }
const Link& GetDoneHdl() const { return aDone; }
- void SetFormat( sal_uIntPtr nFmt ) { aDdeData.SetFormat( nFmt ); }
- sal_uIntPtr GetFormat() const { return aDdeData.GetFormat(); }
+ void SetFormat( sal_uLong nFmt ) { aDdeData.SetFormat( nFmt ); }
+ sal_uLong GetFormat() const { return aDdeData.GetFormat(); }
long GetError();
@@ -253,7 +253,7 @@ class SVL_DLLPUBLIC DdePoke : public DdeTransaction
{
public:
DdePoke( DdeConnection&, const String&, const char*, long,
- sal_uIntPtr = FORMAT_STRING, long = 0 );
+ sal_uLong = FORMAT_STRING, long = 0 );
DdePoke( DdeConnection&, const String&, const DdeData&, long = 0 );
DdePoke( DdeConnection&, const String&, const String&, long = 0 );
};
@@ -312,8 +312,8 @@ class SVL_DLLPUBLIC DdeItem
DdeTopic* pMyTopic;
DdeItemImp* pImpData;
- void IncMonitor( sal_uIntPtr );
- void DecMonitor( sal_uIntPtr );
+ void IncMonitor( sal_uLong );
+ void DecMonitor( sal_uLong );
protected:
sal_uInt8 nType;
@@ -340,7 +340,7 @@ public:
DdeGetPutItem( const String& rStr );
DdeGetPutItem( const DdeItem& rItem );
- virtual DdeData* Get( sal_uIntPtr );
+ virtual DdeData* Get( sal_uLong );
virtual sal_Bool Put( const DdeData* );
virtual void AdviseLoop( sal_Bool ); // AdviseLoop starten/stoppen
};
@@ -356,7 +356,7 @@ class SVL_DLLPUBLIC DdeTopic
public:
virtual void Connect( long );
virtual void Disconnect( long );
- virtual DdeData* Get( sal_uIntPtr );
+ virtual DdeData* Get( sal_uLong );
virtual sal_Bool Put( const DdeData* );
virtual sal_Bool Execute( const String* );
// evt. ein neues anlegen; return 0 -> es konnte nicht angelegt werden
@@ -460,9 +460,9 @@ public:
void AddTopic( const DdeTopic& );
void RemoveTopic( const DdeTopic& );
- void AddFormat( sal_uIntPtr );
- void RemoveFormat( sal_uIntPtr );
- sal_Bool HasFormat( sal_uIntPtr );
+ void AddFormat( sal_uLong );
+ void RemoveFormat( sal_uLong );
+ sal_Bool HasFormat( sal_uLong );
private:
// DdeService( const DdeService& );
diff --git a/svl/inc/svl/svstdarr.hxx b/svl/inc/svl/svstdarr.hxx
index e3377b732ad8..88f318c2d5d3 100644
--- a/svl/inc/svl/svstdarr.hxx
+++ b/svl/inc/svl/svstdarr.hxx
@@ -50,14 +50,14 @@ typedef std::deque< sal_uInt8 > SvBytes;
//#ifdef _SVSTDARR_ULONGS
#ifndef _SVSTDARR_ULONGS_DECL
-SV_DECL_VARARR_VISIBILITY( SvULongs, sal_uIntPtr, 1, 1, SVL_DLLPUBLIC )
+SV_DECL_VARARR_VISIBILITY( SvULongs, sal_uLong, 1, 1, SVL_DLLPUBLIC )
#define _SVSTDARR_ULONGS_DECL
#endif
//#endif
//#ifdef _SVSTDARR_ULONGSSORT
#ifndef _SVSTDARR_ULONGSSORT_DECL
-SV_DECL_VARARR_SORT_VISIBILITY( SvULongsSort, sal_uIntPtr, 1, 1, SVL_DLLPUBLIC )
+SV_DECL_VARARR_SORT_VISIBILITY( SvULongsSort, sal_uLong, 1, 1, SVL_DLLPUBLIC )
#define _SVSTDARR_ULONGSSORT_DECL
#endif
//#endif
diff --git a/svl/inc/svl/zformat.hxx b/svl/inc/svl/zformat.hxx
index 6afaa6105d01..64a336aabc30 100644
--- a/svl/inc/svl/zformat.hxx
+++ b/svl/inc/svl/zformat.hxx
@@ -504,8 +504,8 @@ private:
double& fLimit,
SvNumberformatLimitOps eOp);
- SVL_DLLPRIVATE sal_uIntPtr ImpGGT(sal_uIntPtr x, sal_uIntPtr y);
- SVL_DLLPRIVATE sal_uIntPtr ImpGGTRound(sal_uIntPtr x, sal_uIntPtr y);
+ SVL_DLLPRIVATE sal_uLong ImpGGT(sal_uLong x, sal_uLong y);
+ SVL_DLLPRIVATE sal_uLong ImpGGTRound(sal_uLong x, sal_uLong y);
// Helper function for number strings
// append string symbols, insert leading 0 or ' ', or ...
diff --git a/svl/source/inc/passwordcontainer.hxx b/svl/source/inc/passwordcontainer.hxx
index 6490ea667a6c..e03432906f5f 100644
--- a/svl/source/inc/passwordcontainer.hxx
+++ b/svl/source/inc/passwordcontainer.hxx
@@ -411,13 +411,13 @@ public:
class RW_SvMemoryStream : public SvMemoryStream {
public:
- RW_SvMemoryStream( void* Buf, sal_uIntPtr Size, StreamMode eMode ):
+ RW_SvMemoryStream( void* Buf, sal_uLong Size, StreamMode eMode ):
SvMemoryStream( Buf, Size, eMode){}
- RW_SvMemoryStream( sal_uIntPtr InitSize=512, sal_uIntPtr Resize=64 ):
+ RW_SvMemoryStream( sal_uLong InitSize=512, sal_uLong Resize=64 ):
SvMemoryStream( InitSize, Resize ){}
- sal_uIntPtr getActualSize(){ return nEndOfData; }
+ sal_uLong getActualSize(){ return nEndOfData; }
};
diff --git a/svl/source/items/itemset.cxx b/svl/source/items/itemset.cxx
index 1c7b6a17231b..250e7f99a6ec 100644
--- a/svl/source/items/itemset.cxx
+++ b/svl/source/items/itemset.cxx
@@ -52,7 +52,7 @@
static const sal_uInt16 nInitCount = 10; // einzelne USHORTs => 5 Paare ohne '0'
#ifdef DBG_UTIL
-static sal_uIntPtr nRangesCopyCount = 0; // wie oft wurden Ranges kopiert
+static sal_uLong nRangesCopyCount = 0; // wie oft wurden Ranges kopiert
#endif
DBG_NAME(SfxItemSet)
@@ -67,7 +67,7 @@ DBG_NAME(SfxItemSet)
#undef SvNums
#undef SfxNumRanges
-#define NUMTYPE sal_uIntPtr
+#define NUMTYPE sal_uLong
#define SvNums SvULongs
#define SfxNumRanges SfxULongRanges
#include "nranges.cxx"
@@ -802,7 +802,7 @@ void SfxItemSet::SetRanges( const sal_uInt16 *pNewRanges )
}
// create new item-array (by iterating through all new ranges)
- sal_uIntPtr nSize = Capacity_Impl(pNewRanges);
+ sal_uLong nSize = Capacity_Impl(pNewRanges);
SfxItemArray aNewItems = new const SfxPoolItem* [ nSize ];
sal_uInt16 n = 0, nNewCount = 0;
if ( _nCount == 0 )
@@ -1522,7 +1522,7 @@ SvStream &SfxItemSet::Store
DBG_ASSERTWARNING( _pPool == _pPool->GetMasterPool(), "kein Master-Pool" );
// Position des Counts merken, um ggf. zu korrigieren
- sal_uIntPtr nCountPos = rStream.Tell();
+ sal_uLong nCountPos = rStream.Tell();
rStream << _nCount;
// wenn nichts zu speichern ist, auch keinen ItemIter aufsetzen!
@@ -1549,7 +1549,7 @@ SvStream &SfxItemSet::Store
if ( nWrittenCount != _nCount )
{
// tats"achlichen Count im Stream ablegen
- sal_uIntPtr nPos = rStream.Tell();
+ sal_uLong nPos = rStream.Tell();
rStream.Seek( nCountPos );
rStream << nWrittenCount;
rStream.Seek( nPos );
diff --git a/svl/source/items/lckbitem.cxx b/svl/source/items/lckbitem.cxx
index 38fe0d394f6e..433bfeec1e8e 100644
--- a/svl/source/items/lckbitem.cxx
+++ b/svl/source/items/lckbitem.cxx
@@ -103,13 +103,13 @@ SfxPoolItem* SfxLockBytesItem::Clone(SfxItemPool *) const
SfxPoolItem* SfxLockBytesItem::Create( SvStream &rStream, sal_uInt16 ) const
{
sal_uInt32 nSize = 0;
- sal_uIntPtr nActRead = 0;
+ sal_uLong nActRead = 0;
sal_Char cTmpBuf[MAX_BUF];
SvMemoryStream aNewStream;
rStream >> nSize;
do {
- sal_uIntPtr nToRead;
+ sal_uLong nToRead;
if( (nSize - nActRead) > MAX_BUF )
nToRead = MAX_BUF;
else
@@ -174,7 +174,7 @@ sal_Bool SfxLockBytesItem::QueryValue( com::sun::star::uno::Any& rVal,sal_uInt8
else
return sal_False;
- sal_uIntPtr nRead = 0;
+ sal_uLong nRead = 0;
com::sun::star::uno::Sequence< sal_Int8 > aSeq( nLen );
_xVal->ReadAt( 0, aSeq.getArray(), nLen, &nRead );
diff --git a/svl/source/items/poolitem.cxx b/svl/source/items/poolitem.cxx
index 1f61b336a18a..8626daeffbd5 100644
--- a/svl/source/items/poolitem.cxx
+++ b/svl/source/items/poolitem.cxx
@@ -49,7 +49,7 @@ sal_uInt16 nSfxFlag16Val[16] =
1024, 2048, 4096, 8192, 16384, 32768
};
-sal_uIntPtr nSfxFlag32Val[32] =
+sal_uLong nSfxFlag32Val[32] =
{
0x1L, 0x2L, 0x4L, 0x8L,
0x10L, 0x20L, 0x40L, 0x80L,
@@ -71,7 +71,7 @@ TYPEINIT1(SfxSetItem, SfxPoolItem);
// ------------------------------------------------------------------------
#if OSL_DEBUG_LEVEL > 1
-static sal_uIntPtr nItemCount = 0;
+static sal_uLong nItemCount = 0;
const char* pw1 = "Wow! 10.000 items!";
const char* pw2 = "Wow! 100.000 items!";
diff --git a/svl/source/items/slstitm.cxx b/svl/source/items/slstitm.cxx
index 6d183f111814..be214cccf599 100644
--- a/svl/source/items/slstitm.cxx
+++ b/svl/source/items/slstitm.cxx
@@ -72,7 +72,7 @@ SfxImpStringList::~SfxImpStringList()
void SfxImpStringList::Sort( sal_Bool bAscending, List* pParallelList )
{
DBG_ASSERT(!pParallelList || pParallelList->Count() >= aList.Count(),"Sort:ParallelList too small");
- sal_uIntPtr nCount = aList.Count();
+ sal_uLong nCount = aList.Count();
if( nCount > 1 )
{
nCount -= 2;
@@ -81,7 +81,7 @@ void SfxImpStringList::Sort( sal_Bool bAscending, List* pParallelList )
while( bSwapped )
{
bSwapped = sal_False;
- for( sal_uIntPtr nCur = 0; nCur <= nCount; nCur++ )
+ for( sal_uLong nCur = 0; nCur <= nCount; nCur++ )
{
String* pStr1 = (String*)aList.GetObject( nCur );
String* pStr2 = (String*)aList.GetObject( nCur+1 );
diff --git a/svl/source/items/style.cxx b/svl/source/items/style.cxx
index 1d8c25c085d9..8af4a67ea4f3 100644
--- a/svl/source/items/style.cxx
+++ b/svl/source/items/style.cxx
@@ -333,13 +333,13 @@ SfxItemSet& SfxStyleSheetBase::GetItemSet()
// Hilfe-Datei und -ID setzen und abfragen
-sal_uIntPtr SfxStyleSheetBase::GetHelpId( String& rFile )
+sal_uLong SfxStyleSheetBase::GetHelpId( String& rFile )
{
rFile = aHelpFile;
return nHelpId;
}
-void SfxStyleSheetBase::SetHelpId( const String& rFile, sal_uIntPtr nId )
+void SfxStyleSheetBase::SetHelpId( const String& rFile, sal_uLong nId )
{
aHelpFile = rFile;
nHelpId = nId;
@@ -975,13 +975,13 @@ sal_Bool SfxStyleSheetBasePool::Load( SvStream& rStream )
}
// #72939# only loop through the styles that were really inserted
- sal_uIntPtr n = aStyles.size();
+ sal_uLong n = aStyles.size();
//! delete pTmpPool;
// Jetzt Parent und Follow setzen. Alle Sheets sind geladen.
// Mit Setxxx() noch einmal den String eintragen, da diese
// virtuellen Methoden evtl. ueberlagert sind.
- for ( sal_uIntPtr i = 0; i < n; i++ )
+ for ( sal_uLong i = 0; i < n; i++ )
{
SfxStyleSheetBase* p = aStyles[ i ].get();
XubString aText = p->aParent;
@@ -1220,10 +1220,10 @@ sal_Bool SfxStyleSheetBasePool::Store( SvStream& rStream, sal_Bool bUsed )
// Vor dem lokalen Teil wird die Laenge der lokalen Daten
// als sal_uInt32 sowie die Versionsnummer gespeichert.
rStream << (sal_uInt16) p->GetVersion();
- sal_uIntPtr nPos1 = rStream.Tell();
+ sal_uLong nPos1 = rStream.Tell();
rStream << (sal_uInt32) 0;
p->Store( rStream );
- sal_uIntPtr nPos2 = rStream.Tell();
+ sal_uLong nPos2 = rStream.Tell();
rStream.Seek( nPos1 );
rStream << (sal_uInt32) ( nPos2 - nPos1 - sizeof( sal_uInt32 ) );
rStream.Seek( nPos2 );
diff --git a/svl/source/memtools/svarray.cxx b/svl/source/memtools/svarray.cxx
index 7088d036be3c..f8b190d0cb4c 100644
--- a/svl/source/memtools/svarray.cxx
+++ b/svl/source/memtools/svarray.cxx
@@ -68,11 +68,11 @@ sal_uInt16 SvPtrarr::GetPos( const VoidPtr& aElement ) const
return ( n >= nA ? USHRT_MAX : n );
}
-SV_IMPL_VARARR( SvULongs, sal_uIntPtr )
+SV_IMPL_VARARR( SvULongs, sal_uLong )
SV_IMPL_VARARR( SvUShorts, sal_uInt16 )
SV_IMPL_VARARR( SvLongs, long)
-SV_IMPL_VARARR_SORT( SvULongsSort, sal_uIntPtr )
+SV_IMPL_VARARR_SORT( SvULongsSort, sal_uLong )
SV_IMPL_VARARR_SORT( SvLongsSort, long )
SV_IMPL_PTRARR( SvStrings, StringPtr )
diff --git a/svl/source/misc/adrparse.cxx b/svl/source/misc/adrparse.cxx
index f0faa8ca0504..e21037e0217f 100644
--- a/svl/source/misc/adrparse.cxx
+++ b/svl/source/misc/adrparse.cxx
@@ -774,7 +774,7 @@ SvAddressParser::SvAddressParser(UniString const & rInput): m_bHasFirst(false)
//============================================================================
SvAddressParser::~SvAddressParser()
{
- for (sal_uIntPtr i = m_aRest.Count(); i != 0;)
+ for (sal_uLong i = m_aRest.Count(); i != 0;)
delete m_aRest.Remove(--i);
}
diff --git a/svl/source/misc/inettype.cxx b/svl/source/misc/inettype.cxx
index 4c68922fce3b..86d60bd971ad 100644
--- a/svl/source/misc/inettype.cxx
+++ b/svl/source/misc/inettype.cxx
@@ -633,7 +633,7 @@ Registration * Registration::m_pRegistration = 0;
//============================================================================
Registration::~Registration()
{
- {for (sal_uIntPtr i = 0; i < m_aTypeIDMap.Count(); ++i)
+ {for (sal_uLong i = 0; i < m_aTypeIDMap.Count(); ++i)
delete static_cast< TypeIDMapEntry * >(m_aTypeIDMap.GetObject(i));
}
m_aTypeIDMap.Clear();
diff --git a/svl/source/misc/ownlist.cxx b/svl/source/misc/ownlist.cxx
index 967ec50d0ff5..5d1d728b26e2 100644
--- a/svl/source/misc/ownlist.cxx
+++ b/svl/source/misc/ownlist.cxx
@@ -198,7 +198,7 @@ String SvCommandList::GetCommands() const
*/
{
String aRet;
- for( sal_uIntPtr i = 0; i < aTypes.Count(); i++ )
+ for( sal_uLong i = 0; i < aTypes.Count(); i++ )
{
if( i != 0 )
aRet += ' ';
diff --git a/svl/source/misc/strmadpt.cxx b/svl/source/misc/strmadpt.cxx
index e726601f837d..18f2788077a3 100644
--- a/svl/source/misc/strmadpt.cxx
+++ b/svl/source/misc/strmadpt.cxx
@@ -152,7 +152,7 @@ TYPEINIT1(SvOutputStreamOpenLockBytes, SvOpenLockBytes)
//============================================================================
// virtual
-ErrCode SvOutputStreamOpenLockBytes::ReadAt(sal_uIntPtr, void *, sal_uIntPtr, sal_uIntPtr *)
+ErrCode SvOutputStreamOpenLockBytes::ReadAt(sal_uLong, void *, sal_uLong, sal_uLong *)
const
{
return ERRCODE_IO_CANTREAD;
@@ -160,8 +160,8 @@ ErrCode SvOutputStreamOpenLockBytes::ReadAt(sal_uIntPtr, void *, sal_uIntPtr, sa
//============================================================================
// virtual
-ErrCode SvOutputStreamOpenLockBytes::WriteAt(sal_uIntPtr nPos, void const * pBuffer,
- sal_uIntPtr nCount, sal_uIntPtr * pWritten)
+ErrCode SvOutputStreamOpenLockBytes::WriteAt(sal_uLong nPos, void const * pBuffer,
+ sal_uLong nCount, sal_uLong * pWritten)
{
if (nPos != m_nPosition)
return ERRCODE_IO_CANTWRITE;
@@ -187,7 +187,7 @@ ErrCode SvOutputStreamOpenLockBytes::Flush() const
//============================================================================
// virtual
-ErrCode SvOutputStreamOpenLockBytes::SetSize(sal_uIntPtr)
+ErrCode SvOutputStreamOpenLockBytes::SetSize(sal_uLong)
{
return ERRCODE_IO_NOTSUPPORTED;
}
@@ -205,15 +205,15 @@ ErrCode SvOutputStreamOpenLockBytes::Stat(SvLockBytesStat * pStat,
//============================================================================
// virtual
ErrCode SvOutputStreamOpenLockBytes::FillAppend(void const * pBuffer,
- sal_uIntPtr nCount,
- sal_uIntPtr * pWritten)
+ sal_uLong nCount,
+ sal_uLong * pWritten)
{
if (!m_xOutputStream.is())
return ERRCODE_IO_CANTWRITE;
if (nCount > 0
- && nCount > std::numeric_limits< sal_uIntPtr >::max() - m_nPosition)
+ && nCount > std::numeric_limits< sal_uLong >::max() - m_nPosition)
{
- nCount = std::numeric_limits< sal_uIntPtr >::max() - m_nPosition;
+ nCount = std::numeric_limits< sal_uLong >::max() - m_nPosition;
if (nCount == 0)
return ERRCODE_IO_CANTWRITE;
}
@@ -235,14 +235,14 @@ ErrCode SvOutputStreamOpenLockBytes::FillAppend(void const * pBuffer,
//============================================================================
// virtual
-sal_uIntPtr SvOutputStreamOpenLockBytes::Tell() const
+sal_uLong SvOutputStreamOpenLockBytes::Tell() const
{
return m_nPosition;
}
//============================================================================
// virtual
-sal_uIntPtr SvOutputStreamOpenLockBytes::Seek(sal_uIntPtr)
+sal_uLong SvOutputStreamOpenLockBytes::Seek(sal_uLong)
{
return m_nPosition;
}
@@ -476,7 +476,7 @@ bool SvInputStream::open()
//============================================================================
// virtual
-sal_uIntPtr SvInputStream::GetData(void * pData, sal_uIntPtr nSize)
+sal_uLong SvInputStream::GetData(void * pData, sal_uLong nSize)
{
if (!open())
{
@@ -503,8 +503,8 @@ sal_uIntPtr SvInputStream::GetData(void * pData, sal_uIntPtr nSize)
{
sal_Int32 nRemain
= sal_Int32(
- std::min(sal_uIntPtr(nSize - nRead),
- sal_uIntPtr(std::numeric_limits< sal_Int32 >::max())));
+ std::min(sal_uLong(nSize - nRead),
+ sal_uLong(std::numeric_limits< sal_Int32 >::max())));
if (nRemain == 0)
break;
uno::Sequence< sal_Int8 > aBuffer;
@@ -540,8 +540,8 @@ sal_uIntPtr SvInputStream::GetData(void * pData, sal_uIntPtr nSize)
sal_Int32 nRemain
= sal_Int32(
std::min(
- sal_uIntPtr(nSize - nRead),
- sal_uIntPtr(std::numeric_limits< sal_Int32 >::max())));
+ sal_uLong(nSize - nRead),
+ sal_uLong(std::numeric_limits< sal_Int32 >::max())));
if (nRemain == 0)
break;
uno::Sequence< sal_Int8 > aBuffer;
@@ -571,7 +571,7 @@ sal_uIntPtr SvInputStream::GetData(void * pData, sal_uIntPtr nSize)
//============================================================================
// virtual
-sal_uIntPtr SvInputStream::PutData(void const *, sal_uIntPtr)
+sal_uLong SvInputStream::PutData(void const *, sal_uLong)
{
SetError(ERRCODE_IO_NOTSUPPORTED);
return 0;
@@ -584,7 +584,7 @@ void SvInputStream::FlushData()
//============================================================================
// virtual
-sal_uIntPtr SvInputStream::SeekPos(sal_uIntPtr nPos)
+sal_uLong SvInputStream::SeekPos(sal_uLong nPos)
{
if (open())
{
@@ -601,7 +601,7 @@ sal_uIntPtr SvInputStream::SeekPos(sal_uIntPtr nPos)
< STREAM_SEEK_TO_END)
{
m_nSeekedFrom = Tell();
- return sal_uIntPtr(nLength);
+ return sal_uLong(nLength);
}
}
catch (io::IOException) {}
@@ -636,7 +636,7 @@ sal_uIntPtr SvInputStream::SeekPos(sal_uIntPtr nPos)
//============================================================================
// virtual
-void SvInputStream::SetSize(sal_uIntPtr)
+void SvInputStream::SetSize(sal_uLong)
{
SetError(ERRCODE_IO_NOTSUPPORTED);
}
@@ -675,7 +675,7 @@ sal_uInt16 SvInputStream::IsA() const
//============================================================================
// virtual
-void SvInputStream::AddMark(sal_uIntPtr nPos)
+void SvInputStream::AddMark(sal_uLong nPos)
{
if (open() && m_pPipe)
m_pPipe->addMark(nPos);
@@ -683,7 +683,7 @@ void SvInputStream::AddMark(sal_uIntPtr nPos)
//============================================================================
// virtual
-void SvInputStream::RemoveMark(sal_uIntPtr nPos)
+void SvInputStream::RemoveMark(sal_uLong nPos)
{
if (open() && m_pPipe)
m_pPipe->removeMark(nPos);
@@ -696,7 +696,7 @@ void SvInputStream::RemoveMark(sal_uIntPtr nPos)
//============================================================================
// virtual
-sal_uIntPtr SvOutputStream::GetData(void *, sal_uIntPtr)
+sal_uLong SvOutputStream::GetData(void *, sal_uLong)
{
SetError(ERRCODE_IO_NOTSUPPORTED);
return 0;
@@ -704,20 +704,20 @@ sal_uIntPtr SvOutputStream::GetData(void *, sal_uIntPtr)
//============================================================================
// virtual
-sal_uIntPtr SvOutputStream::PutData(void const * pData, sal_uIntPtr nSize)
+sal_uLong SvOutputStream::PutData(void const * pData, sal_uLong nSize)
{
if (!m_xStream.is())
{
SetError(ERRCODE_IO_CANTWRITE);
return 0;
}
- sal_uIntPtr nWritten = 0;
+ sal_uLong nWritten = 0;
for (;;)
{
sal_Int32 nRemain
= sal_Int32(
- std::min(sal_uIntPtr(nSize - nWritten),
- sal_uIntPtr(std::numeric_limits< sal_Int32 >::max())));
+ std::min(sal_uLong(nSize - nWritten),
+ sal_uLong(std::numeric_limits< sal_Int32 >::max())));
if (nRemain == 0)
break;
try
@@ -739,7 +739,7 @@ sal_uIntPtr SvOutputStream::PutData(void const * pData, sal_uIntPtr nSize)
//============================================================================
// virtual
-sal_uIntPtr SvOutputStream::SeekPos(sal_uIntPtr)
+sal_uLong SvOutputStream::SeekPos(sal_uLong)
{
SetError(ERRCODE_IO_NOTSUPPORTED);
return 0;
@@ -763,7 +763,7 @@ void SvOutputStream::FlushData()
//============================================================================
// virtual
-void SvOutputStream::SetSize(sal_uIntPtr)
+void SvOutputStream::SetSize(sal_uLong)
{
SetError(ERRCODE_IO_NOTSUPPORTED);
}
diff --git a/svl/source/notify/smplhint.cxx b/svl/source/notify/smplhint.cxx
index 3a750f2f9a44..9191e50f383e 100644
--- a/svl/source/notify/smplhint.cxx
+++ b/svl/source/notify/smplhint.cxx
@@ -39,7 +39,7 @@ TYPEINIT1(SfxSimpleHint, SfxHint);
//====================================================================
// creates a SimpleHint with the type nId
-SfxSimpleHint::SfxSimpleHint( sal_uIntPtr nIdP )
+SfxSimpleHint::SfxSimpleHint( sal_uLong nIdP )
{
nId = nIdP;
}
diff --git a/svl/source/numbers/numfmuno.cxx b/svl/source/numbers/numfmuno.cxx
index a0af8caef8ae..3a4949f45cbc 100644
--- a/svl/source/numbers/numfmuno.cxx
+++ b/svl/source/numbers/numfmuno.cxx
@@ -715,7 +715,7 @@ uno::Sequence<rtl::OUString> SAL_CALL SvNumberFormatsObj::getSupportedServiceNam
//------------------------------------------------------------------------
-SvNumberFormatObj::SvNumberFormatObj( SvNumberFormatsSupplierObj& rParent, sal_uIntPtr nK, const ::comphelper::SharedMutex& _rMutex )
+SvNumberFormatObj::SvNumberFormatObj( SvNumberFormatsSupplierObj& rParent, sal_uLong nK, const ::comphelper::SharedMutex& _rMutex )
:rSupplier( rParent )
,nKey( nK )
,m_aMutex( _rMutex )
diff --git a/svl/source/numbers/numfmuno.hxx b/svl/source/numbers/numfmuno.hxx
index f60d0088f950..f3644cc4e7a5 100644
--- a/svl/source/numbers/numfmuno.hxx
+++ b/svl/source/numbers/numfmuno.hxx
@@ -183,11 +183,11 @@ class SvNumberFormatObj : public cppu::WeakImplHelper3<
{
private:
SvNumberFormatsSupplierObj& rSupplier;
- sal_uIntPtr nKey;
+ sal_uLong nKey;
mutable ::comphelper::SharedMutex m_aMutex;
public:
- SvNumberFormatObj( SvNumberFormatsSupplierObj& rParent, sal_uIntPtr nK, const ::comphelper::SharedMutex& _rMutex );
+ SvNumberFormatObj( SvNumberFormatsSupplierObj& rParent, sal_uLong nK, const ::comphelper::SharedMutex& _rMutex );
virtual ~SvNumberFormatObj();
// XPropertySet
diff --git a/svl/source/numbers/numhead.cxx b/svl/source/numbers/numhead.cxx
index dc481d1f184c..98ed17982444 100644
--- a/svl/source/numbers/numhead.cxx
+++ b/svl/source/numbers/numhead.cxx
@@ -47,7 +47,7 @@
SvNumReadHeader::SvNumReadHeader(SvStream& rNewStream) :
rStream( rNewStream )
{
- sal_uIntPtr nDataSize;
+ sal_uLong nDataSize;
rStream >> nDataSize;
nDataEnd = rStream.Tell() + nDataSize;
}
@@ -56,7 +56,7 @@ SvNumReadHeader::SvNumReadHeader(SvStream& rNewStream) :
SvNumReadHeader::~SvNumReadHeader()
{
- sal_uIntPtr nReadEnd = rStream.Tell();
+ sal_uLong nReadEnd = rStream.Tell();
DBG_ASSERT( nReadEnd <= nDataEnd, "zuviele Bytes gelesen" );
if ( nReadEnd != nDataEnd )
rStream.Seek(nDataEnd); // Rest ueberspringen
@@ -64,9 +64,9 @@ SvNumReadHeader::~SvNumReadHeader()
//#pragma SEG_FUNCDEF(numhead_03)
-sal_uIntPtr SvNumReadHeader::BytesLeft() const
+sal_uLong SvNumReadHeader::BytesLeft() const
{
- sal_uIntPtr nReadEnd = rStream.Tell();
+ sal_uLong nReadEnd = rStream.Tell();
if (nReadEnd <= nDataEnd)
return nDataEnd-nReadEnd;
@@ -78,7 +78,7 @@ sal_uIntPtr SvNumReadHeader::BytesLeft() const
//#pragma SEG_FUNCDEF(numhead_04)
-SvNumWriteHeader::SvNumWriteHeader(SvStream& rNewStream, sal_uIntPtr nDefault) :
+SvNumWriteHeader::SvNumWriteHeader(SvStream& rNewStream, sal_uLong nDefault) :
rStream( rNewStream )
{
nDataSize = nDefault;
@@ -90,7 +90,7 @@ SvNumWriteHeader::SvNumWriteHeader(SvStream& rNewStream, sal_uIntPtr nDefault) :
SvNumWriteHeader::~SvNumWriteHeader()
{
- sal_uIntPtr nPos = rStream.Tell();
+ sal_uLong nPos = rStream.Tell();
if ( nPos - nDataPos != nDataSize ) // Default getroffen?
{
@@ -112,7 +112,7 @@ ImpSvNumMultipleReadHeader::ImpSvNumMultipleReadHeader(SvStream& rNewStream) :
{
sal_uInt32 nDataSize;
rStream >> nDataSize;
- sal_uIntPtr nDataPos = rStream.Tell();
+ sal_uLong nDataPos = rStream.Tell();
nEntryEnd = nDataPos;
rStream.SeekRel(nDataSize);
@@ -166,7 +166,7 @@ void ImpSvNumMultipleReadHeader::Skip( SvStream& rStream )
void ImpSvNumMultipleReadHeader::EndEntry()
{
- sal_uIntPtr nPos = rStream.Tell();
+ sal_uLong nPos = rStream.Tell();
DBG_ASSERT( nPos <= nEntryEnd, "zuviel gelesen" );
if ( nPos != nEntryEnd )
rStream.Seek( nEntryEnd ); // Rest ueberspringen
@@ -176,7 +176,7 @@ void ImpSvNumMultipleReadHeader::EndEntry()
void ImpSvNumMultipleReadHeader::StartEntry()
{
- sal_uIntPtr nPos = rStream.Tell();
+ sal_uLong nPos = rStream.Tell();
sal_uInt32 nEntrySize;
(*pMemStream) >> nEntrySize;
@@ -185,9 +185,9 @@ void ImpSvNumMultipleReadHeader::StartEntry()
//#pragma SEG_FUNCDEF(numhead_09)
-sal_uIntPtr ImpSvNumMultipleReadHeader::BytesLeft() const
+sal_uLong ImpSvNumMultipleReadHeader::BytesLeft() const
{
- sal_uIntPtr nReadEnd = rStream.Tell();
+ sal_uLong nReadEnd = rStream.Tell();
if (nReadEnd <= nEntryEnd)
return nEntryEnd-nReadEnd;
@@ -200,7 +200,7 @@ sal_uIntPtr ImpSvNumMultipleReadHeader::BytesLeft() const
//#pragma SEG_FUNCDEF(numhead_0a)
ImpSvNumMultipleWriteHeader::ImpSvNumMultipleWriteHeader(SvStream& rNewStream,
- sal_uIntPtr nDefault) :
+ sal_uLong nDefault) :
rStream( rNewStream ),
aMemStream( 4096, 4096 )
{
@@ -215,7 +215,7 @@ ImpSvNumMultipleWriteHeader::ImpSvNumMultipleWriteHeader(SvStream& rNewStream,
ImpSvNumMultipleWriteHeader::~ImpSvNumMultipleWriteHeader()
{
- sal_uIntPtr nDataEnd = rStream.Tell();
+ sal_uLong nDataEnd = rStream.Tell();
rStream << (sal_uInt16) SV_NUMID_SIZES;
rStream << static_cast<sal_uInt32>(aMemStream.Tell());
@@ -224,7 +224,7 @@ ImpSvNumMultipleWriteHeader::~ImpSvNumMultipleWriteHeader()
if ( nDataEnd - nDataPos != nDataSize ) // Default getroffen?
{
nDataSize = nDataEnd - nDataPos;
- sal_uIntPtr nPos = rStream.Tell();
+ sal_uLong nPos = rStream.Tell();
rStream.Seek(nDataPos-sizeof(sal_uInt32));
rStream << nDataSize; // Groesse am Anfang eintragen
rStream.Seek(nPos);
@@ -235,7 +235,7 @@ ImpSvNumMultipleWriteHeader::~ImpSvNumMultipleWriteHeader()
void ImpSvNumMultipleWriteHeader::EndEntry()
{
- sal_uIntPtr nPos = rStream.Tell();
+ sal_uLong nPos = rStream.Tell();
aMemStream << static_cast<sal_uInt32>(nPos - nEntryStart);
}
@@ -243,7 +243,7 @@ void ImpSvNumMultipleWriteHeader::EndEntry()
void ImpSvNumMultipleWriteHeader::StartEntry()
{
- sal_uIntPtr nPos = rStream.Tell();
+ sal_uLong nPos = rStream.Tell();
nEntryStart = nPos;
}
diff --git a/svl/source/numbers/numhead.hxx b/svl/source/numbers/numhead.hxx
index 6ed95c39e3d5..c268d1869b8a 100644
--- a/svl/source/numbers/numhead.hxx
+++ b/svl/source/numbers/numhead.hxx
@@ -39,24 +39,24 @@ class SvNumReadHeader
{
private:
SvStream& rStream;
- sal_uIntPtr nDataEnd;
+ sal_uLong nDataEnd;
public:
SvNumReadHeader(SvStream& rNewStream);
~SvNumReadHeader();
- sal_uIntPtr BytesLeft() const;
+ sal_uLong BytesLeft() const;
};
class SvNumWriteHeader
{
private:
SvStream& rStream;
- sal_uIntPtr nDataPos;
- sal_uIntPtr nDataSize;
+ sal_uLong nDataPos;
+ sal_uLong nDataSize;
public:
- SvNumWriteHeader(SvStream& rNewStream, sal_uIntPtr nDefault = 0);
+ SvNumWriteHeader(SvStream& rNewStream, sal_uLong nDefault = 0);
~SvNumWriteHeader();
};
@@ -70,8 +70,8 @@ private:
SvStream& rStream;
char* pBuf;
SvMemoryStream* pMemStream;
- sal_uIntPtr nEndPos;
- sal_uIntPtr nEntryEnd;
+ sal_uLong nEndPos;
+ sal_uLong nEntryEnd;
public:
ImpSvNumMultipleReadHeader(SvStream& rNewStream);
@@ -79,7 +79,7 @@ public:
void StartEntry();
void EndEntry();
- sal_uIntPtr BytesLeft() const;
+ sal_uLong BytesLeft() const;
static void Skip( SvStream& ); // komplett ueberspringen
};
@@ -89,12 +89,12 @@ class ImpSvNumMultipleWriteHeader
private:
SvStream& rStream;
SvMemoryStream aMemStream;
- sal_uIntPtr nDataPos;
+ sal_uLong nDataPos;
sal_uInt32 nDataSize;
- sal_uIntPtr nEntryStart;
+ sal_uLong nEntryStart;
public:
- ImpSvNumMultipleWriteHeader(SvStream& rNewStream, sal_uIntPtr nDefault = 0);
+ ImpSvNumMultipleWriteHeader(SvStream& rNewStream, sal_uLong nDefault = 0);
~ImpSvNumMultipleWriteHeader();
void StartEntry();
diff --git a/svl/source/numbers/zforlist.cxx b/svl/source/numbers/zforlist.cxx
index b7cae8f69562..ebc1fa673fe2 100644
--- a/svl/source/numbers/zforlist.cxx
+++ b/svl/source/numbers/zforlist.cxx
@@ -1334,7 +1334,7 @@ sal_uInt32 SvNumberFormatter::ImpGetDefaultFormat( short nType )
default:
nSearch = CLOffset + ZF_STANDARD;
}
- sal_uInt32 nDefaultFormat = (sal_uInt32)(sal_uIntPtr) aDefaultFormatKeys.Get( nSearch );
+ sal_uInt32 nDefaultFormat = (sal_uInt32)(sal_uLong) aDefaultFormatKeys.Get( nSearch );
if ( !nDefaultFormat )
nDefaultFormat = NUMBERFORMAT_ENTRY_NOT_FOUND;
if ( nDefaultFormat == NUMBERFORMAT_ENTRY_NOT_FOUND )
@@ -3207,7 +3207,7 @@ sal_uInt32 SvNumberFormatter::ImpGetDefaultCurrencyFormat()
{
sal_uInt32 CLOffset = ImpGetCLOffset( ActLnge );
sal_uInt32 nDefaultCurrencyFormat =
- (sal_uInt32)(sal_uIntPtr) aDefaultFormatKeys.Get( CLOffset + ZF_STANDARD_CURRENCY );
+ (sal_uInt32)(sal_uLong) aDefaultFormatKeys.Get( CLOffset + ZF_STANDARD_CURRENCY );
if ( !nDefaultCurrencyFormat )
nDefaultCurrencyFormat = NUMBERFORMAT_ENTRY_NOT_FOUND;
if ( nDefaultCurrencyFormat == NUMBERFORMAT_ENTRY_NOT_FOUND )
diff --git a/svl/source/numbers/zformat.cxx b/svl/source/numbers/zformat.cxx
index 3345a19513bd..92398792077d 100644
--- a/svl/source/numbers/zformat.cxx
+++ b/svl/source/numbers/zformat.cxx
@@ -1935,21 +1935,21 @@ sal_Bool SvNumberformat::GetOutputString(String& sString,
return sal_False;
}
/*
-void SvNumberformat::GetNextFareyNumber(sal_uIntPtr nPrec, sal_uIntPtr x0, sal_uIntPtr x1,
- sal_uIntPtr y0, sal_uIntPtr y1,
- sal_uIntPtr& x2,sal_uIntPtr& y2)
+void SvNumberformat::GetNextFareyNumber(sal_uLong nPrec, sal_uLong x0, sal_uLong x1,
+ sal_uLong y0, sal_uLong y1,
+ sal_uLong& x2,sal_uLong& y2)
{
x2 = ((y0+nPrec)/y1)*x1 - x0;
y2 = ((y0+nPrec)/y1)*y1 - y0;
}
*/
-sal_uIntPtr SvNumberformat::ImpGGT(sal_uIntPtr x, sal_uIntPtr y)
+sal_uLong SvNumberformat::ImpGGT(sal_uLong x, sal_uLong y)
{
if (y == 0)
return x;
else
{
- sal_uIntPtr z = x%y;
+ sal_uLong z = x%y;
while (z)
{
x = y;
@@ -1960,13 +1960,13 @@ sal_uIntPtr SvNumberformat::ImpGGT(sal_uIntPtr x, sal_uIntPtr y)
}
}
-sal_uIntPtr SvNumberformat::ImpGGTRound(sal_uIntPtr x, sal_uIntPtr y)
+sal_uLong SvNumberformat::ImpGGTRound(sal_uLong x, sal_uLong y)
{
if (y == 0)
return x;
else
{
- sal_uIntPtr z = x%y;
+ sal_uLong z = x%y;
while ((double)z/(double)y > D_EPS)
{
x = y;
@@ -2198,7 +2198,7 @@ sal_Bool SvNumberformat::GetOutputString(double fNumber,
case NUMBERFORMAT_FRACTION:
{
String sStr, sFrac, sDiv; // Strings, Wert fuer
- sal_uIntPtr nFrac, nDiv; // Vorkommaanteil
+ sal_uLong nFrac, nDiv; // Vorkommaanteil
// Zaehler und Nenner
sal_Bool bSign = sal_False;
if (fNumber < 0)
@@ -2220,9 +2220,9 @@ sal_Bool SvNumberformat::GetOutputString(double fNumber,
DBG_ERROR("SvNumberformat:: Bruch, nCntExp == 0");
return sal_False;
}
- sal_uIntPtr nBasis = ((sal_uIntPtr)floor( // 9, 99, 999 ,...
+ sal_uLong nBasis = ((sal_uLong)floor( // 9, 99, 999 ,...
pow(10.0,rInfo.nCntExp))) - 1;
- sal_uIntPtr x0, y0, x1, y1;
+ sal_uLong x0, y0, x1, y1;
if (rInfo.nCntExp <= _MAX_FRACTION_PREC)
{
@@ -2236,7 +2236,7 @@ sal_Bool SvNumberformat::GetOutputString(double fNumber,
bUpperHalf = sal_False;
// Einstieg in Farey-Serie
// finden:
- x0 = (sal_uIntPtr) floor(fNumber*nBasis); // z.B. 2/9 <= x < 3/9
+ x0 = (sal_uLong) floor(fNumber*nBasis); // z.B. 2/9 <= x < 3/9
if (x0 == 0) // => x0 = 2
{
y0 = 1;
@@ -2262,11 +2262,11 @@ sal_Bool SvNumberformat::GetOutputString(double fNumber,
y1 = nBasis - 1;
double fUg = (double) x0 / (double) y0;
double fOg = (double) x1 / (double) y1;
- sal_uIntPtr nGgt = ImpGGT(y0, x0); // x0/y0 kuerzen
+ sal_uLong nGgt = ImpGGT(y0, x0); // x0/y0 kuerzen
x0 /= nGgt;
y0 /= nGgt; // Einschachteln:
- sal_uIntPtr x2 = 0;
- sal_uIntPtr y2 = 0;
+ sal_uLong x2 = 0;
+ sal_uLong y2 = 0;
sal_Bool bStop = sal_False;
while (!bStop)
{
@@ -2315,8 +2315,8 @@ sal_Bool SvNumberformat::GetOutputString(double fNumber,
fup = (double)x1/(double)y1;
while (fNumber > fup)
{
- sal_uIntPtr x2 = ((y0+nBasis)/y1)*x1 - x0; // naechste Farey-Zahl
- sal_uIntPtr y2 = ((y0+nBasis)/y1)*y1 - y0;
+ sal_uLong x2 = ((y0+nBasis)/y1)*x1 - x0; // naechste Farey-Zahl
+ sal_uLong y2 = ((y0+nBasis)/y1)*y1 - y0;
// GetNextFareyNumber(nBasis, x0, x1, y0, y1, x2, y2);
x0 = x1;
y0 = y1;
@@ -2345,14 +2345,14 @@ sal_Bool SvNumberformat::GetOutputString(double fNumber,
}
else // grosse Nenner
{ // 0,1234->123/1000
- sal_uIntPtr nGgt;
+ sal_uLong nGgt;
/*
nDiv = nBasis+1;
- nFrac = ((sal_uIntPtr)floor(0.5 + fNumber *
+ nFrac = ((sal_uLong)floor(0.5 + fNumber *
pow(10.0,rInfo.nCntExp)));
*/
nDiv = 10000000;
- nFrac = ((sal_uIntPtr)floor(0.5 + fNumber * 10000000.0));
+ nFrac = ((sal_uLong)floor(0.5 + fNumber * 10000000.0));
nGgt = ImpGGT(nDiv, nFrac);
if (nGgt > 1)
{
@@ -2371,7 +2371,7 @@ sal_Bool SvNumberformat::GetOutputString(double fNumber,
if (nDiv > nBasis)
{
nDiv = nBasis;
- nFrac = ((sal_uIntPtr)floor(0.5 + fNumber *
+ nFrac = ((sal_uLong)floor(0.5 + fNumber *
pow(10.0,rInfo.nCntExp)));
nGgt = ImpGGTRound(nDiv, nFrac);
if (nGgt > 1)
@@ -2390,7 +2390,7 @@ sal_Bool SvNumberformat::GetOutputString(double fNumber,
OutString = rScan.GetErrorString();
return sal_False;
}
- nFrac = (sal_uIntPtr) floor(fNum1);
+ nFrac = (sal_uLong) floor(fNum1);
sStr.Erase();
}
else if (fNum == 0.0 && nFrac != 0)
@@ -2601,7 +2601,7 @@ sal_Bool SvNumberformat::ImpGetTimeOutput(double fNumber,
OutString = rScan.GetErrorString();
return sal_False;
}
- sal_uIntPtr nSeconds = (sal_uIntPtr)floor( fTime );
+ sal_uLong nSeconds = (sal_uLong)floor( fTime );
String sSecStr( ::rtl::math::doubleToUString( fTime-nSeconds,
rtl_math_StringFormat_F, int(nCntPost), '.'));
@@ -2620,7 +2620,7 @@ sal_Bool SvNumberformat::ImpGetTimeOutput(double fNumber,
xub_StrLen nSecPos = 0; // Zum Ziffernweisen
// abarbeiten
- sal_uIntPtr nHour, nMin, nSec;
+ sal_uLong nHour, nMin, nSec;
if (!rInfo.bThousand) // kein [] Format
{
nHour = (nSeconds/3600) % 24;
@@ -3133,7 +3133,7 @@ sal_Bool SvNumberformat::ImpGetDateTimeOutput(double fNumber,
bOtherCalendar = sal_False;
sal_Int16 nNatNum = NumFor[nIx].GetNatNum().GetNatNum();
- sal_uIntPtr nSeconds = (sal_uIntPtr)floor( fTime );
+ sal_uLong nSeconds = (sal_uLong)floor( fTime );
String sSecStr( ::rtl::math::doubleToUString( fTime-nSeconds,
rtl_math_StringFormat_F, int(nCntPost), '.'));
sSecStr.EraseLeadingChars('0');
@@ -3151,7 +3151,7 @@ sal_Bool SvNumberformat::ImpGetDateTimeOutput(double fNumber,
xub_StrLen nSecPos = 0; // Zum Ziffernweisen
// abarbeiten
- sal_uIntPtr nHour, nMin, nSec;
+ sal_uLong nHour, nMin, nSec;
if (!rInfo.bThousand) // [] Format
{
nHour = (nSeconds/3600) % 24;
diff --git a/svl/source/svdde/ddecli.cxx b/svl/source/svdde/ddecli.cxx
index d165d98fa684..ec1adf1fd300 100644
--- a/svl/source/svdde/ddecli.cxx
+++ b/svl/source/svdde/ddecli.cxx
@@ -306,7 +306,7 @@ void DdeTransaction::Execute()
HSZ hItem = *pName;
void* pData = (void*)(const void *)aDdeData;
DWORD nData = (DWORD)(long)aDdeData;
- sal_uIntPtr nIntFmt = aDdeData.pImp->nFmt;
+ sal_uLong nIntFmt = aDdeData.pImp->nFmt;
UINT nExtFmt = DdeData::GetExternalFormat( nIntFmt );
DdeInstData* pInst = ImpGetInstData();
@@ -427,7 +427,7 @@ DdeHotLink::DdeHotLink( DdeConnection& d, const String& i, long n ) :
// --- DdePoke::DdePoke() ------------------------------------------
DdePoke::DdePoke( DdeConnection& d, const String& i, const char* p,
- long l, sal_uIntPtr f, long n ) :
+ long l, sal_uLong f, long n ) :
DdeTransaction( d, i, n )
{
aDdeData = DdeData( p, l, f );
diff --git a/svl/source/svdde/ddedata.cxx b/svl/source/svdde/ddedata.cxx
index 8e5be5eecca3..7f78f4d4398a 100644
--- a/svl/source/svdde/ddedata.cxx
+++ b/svl/source/svdde/ddedata.cxx
@@ -54,7 +54,7 @@ DdeData::DdeData()
// --- DdeData::DdeData() ------------------------------------------
-DdeData::DdeData( const void* p, long n, sal_uIntPtr f )
+DdeData::DdeData( const void* p, long n, sal_uLong f )
{
pImp = new DdeDataImp;
pImp->hData = NULL;
@@ -105,12 +105,12 @@ void DdeData::Lock()
// --- DdeData::GetFormat() ----------------------------------------
-sal_uIntPtr DdeData::GetFormat() const
+sal_uLong DdeData::GetFormat() const
{
return pImp->nFmt;
}
-void DdeData::SetFormat( sal_uIntPtr nFmt )
+void DdeData::SetFormat( sal_uLong nFmt )
{
pImp->nFmt = nFmt;
}
@@ -144,7 +144,7 @@ DdeData& DdeData::operator = ( const DdeData& rData )
return *this;
}
-sal_uIntPtr DdeData::GetExternalFormat( sal_uIntPtr nFmt )
+sal_uLong DdeData::GetExternalFormat( sal_uLong nFmt )
{
switch( nFmt )
{
@@ -173,7 +173,7 @@ sal_uIntPtr DdeData::GetExternalFormat( sal_uIntPtr nFmt )
if( aName.Len() )
{
HATOMTBL hSysTable = WinQuerySystemAtomTable();
- nFmt = (sal_uIntPtr)WinAddAtom( hSysTable, (PSZ)aName.GetBuffer() );
+ nFmt = (sal_uLong)WinAddAtom( hSysTable, (PSZ)aName.GetBuffer() );
}
#endif
#endif
@@ -182,7 +182,7 @@ sal_uIntPtr DdeData::GetExternalFormat( sal_uIntPtr nFmt )
return nFmt;
}
-sal_uIntPtr DdeData::GetInternalFormat( sal_uIntPtr nFmt )
+sal_uLong DdeData::GetInternalFormat( sal_uLong nFmt )
{
switch( nFmt )
{
diff --git a/svl/source/svdde/ddeimp.hxx b/svl/source/svdde/ddeimp.hxx
index 62f41a307efc..cef0bb386201 100644
--- a/svl/source/svdde/ddeimp.hxx
+++ b/svl/source/svdde/ddeimp.hxx
@@ -33,10 +33,10 @@
#include "ddemlos2.h"
#define WORD sal_uInt16
-#define DWORD sal_uIntPtr
+#define DWORD sal_uLong
#define LPBYTE sal_uInt8*
#define LPWORD sal_uInt16*
-#define LPDWORD sal_uIntPtr*
+#define LPDWORD sal_uLong*
#define LPCTSTR PCSZ
#else
@@ -143,7 +143,7 @@ struct DdeDataImp
HDDEDATA hData;
LPBYTE pData;
long nData;
- sal_uIntPtr nFmt;
+ sal_uLong nFmt;
};
class DdeConnections;
@@ -155,11 +155,11 @@ struct DdeInstData
DdeConnections* pConnections;
// Server
long hCurConvSvr;
- sal_uIntPtr hDdeInstSvr;
+ sal_uLong hDdeInstSvr;
short nInstanceSvr;
DdeServices* pServicesSvr;
// Client
- sal_uIntPtr hDdeInstCli;
+ sal_uLong hDdeInstCli;
short nInstanceCli;
};
diff --git a/svl/source/svdde/ddesvr.cxx b/svl/source/svdde/ddesvr.cxx
index 25d1cf380c03..3d3c5029c6a7 100644
--- a/svl/source/svdde/ddesvr.cxx
+++ b/svl/source/svdde/ddesvr.cxx
@@ -48,10 +48,10 @@ enum DdeItemType
struct DdeItemImpData
{
- sal_uIntPtr nHCnv;
+ sal_uLong nHCnv;
sal_uInt16 nCnt;
- DdeItemImpData( sal_uIntPtr nH ) : nHCnv( nH ), nCnt( 1 ) {}
+ DdeItemImpData( sal_uLong nH ) : nHCnv( nH ), nCnt( 1 ) {}
};
SV_DECL_VARARR( DdeItemImp, DdeItemImpData, 1, 1 )
@@ -569,7 +569,7 @@ void DdeService::RemoveTopic( const DdeTopic& rTopic )
aTopics.Remove( t );
// JP 27.07.95: und alle Conversions loeschen !!!
// (sonst wird auf geloeschten Topics gearbeitet!!)
- for( sal_uIntPtr n = pConv->Count(); n; )
+ for( sal_uLong n = pConv->Count(); n; )
{
Conversation* pC = pConv->GetObject( --n );
if( pC->pTopic == &rTopic )
@@ -592,14 +592,14 @@ sal_Bool DdeService::HasCbFormat( sal_uInt16 nFmt )
// --- DdeService::HasFormat() -------------------------------------
-sal_Bool DdeService::HasFormat( sal_uIntPtr nFmt )
+sal_Bool DdeService::HasFormat( sal_uLong nFmt )
{
return HasCbFormat( (sal_uInt16)DdeData::GetExternalFormat( nFmt ));
}
// --- DdeService::AddFormat() -------------------------------------
-void DdeService::AddFormat( sal_uIntPtr nFmt )
+void DdeService::AddFormat( sal_uLong nFmt )
{
nFmt = DdeData::GetExternalFormat( nFmt );
aFormats.Remove( nFmt );
@@ -608,7 +608,7 @@ void DdeService::AddFormat( sal_uIntPtr nFmt )
// --- DdeService::RemoveFormat() ----------------------------------
-void DdeService::RemoveFormat( sal_uIntPtr nFmt )
+void DdeService::RemoveFormat( sal_uLong nFmt )
{
aFormats.Remove( DdeData::GetExternalFormat( nFmt ) );
}
@@ -741,7 +741,7 @@ void __EXPORT DdeTopic::_Disconnect( long nId )
// --- DdeTopic::Get() ---------------------------------------------
-DdeData* __EXPORT DdeTopic::Get( sal_uIntPtr nFmt )
+DdeData* __EXPORT DdeTopic::Get( sal_uLong nFmt )
{
if ( aGetLink.IsSet() )
return (DdeData*)aGetLink.Call( (void*)nFmt );
@@ -859,7 +859,7 @@ void DdeItem::NotifyClient()
// --- DdeItem::IncMonitor() ------------------------------------------
-void DdeItem::IncMonitor( sal_uIntPtr nHCnv )
+void DdeItem::IncMonitor( sal_uLong nHCnv )
{
if( !pImpData )
{
@@ -882,7 +882,7 @@ void DdeItem::IncMonitor( sal_uIntPtr nHCnv )
// --- DdeItem::DecMonitor() ------------------------------------------
-void DdeItem::DecMonitor( sal_uIntPtr nHCnv )
+void DdeItem::DecMonitor( sal_uLong nHCnv )
{
if( pImpData )
{
@@ -944,7 +944,7 @@ DdeGetPutItem::DdeGetPutItem( const DdeItem& rItem )
// --- DdeGetPutData::Get() ----------------------------------------
-DdeData* DdeGetPutItem::Get( sal_uIntPtr )
+DdeData* DdeGetPutItem::Get( sal_uLong )
{
return 0;
}
diff --git a/svl/unx/source/svdde/ddedummy.cxx b/svl/unx/source/svdde/ddedummy.cxx
index 6acf11144a7c..e769ee73b9cb 100644
--- a/svl/unx/source/svdde/ddedummy.cxx
+++ b/svl/unx/source/svdde/ddedummy.cxx
@@ -42,7 +42,7 @@ DdeData::DdeData( const DdeData& )
{
}
-DdeData::DdeData( const void*, long, sal_uIntPtr)
+DdeData::DdeData( const void*, long, sal_uLong)
{
}
@@ -50,11 +50,11 @@ DdeData::~DdeData( void )
{
}
-void DdeData::SetFormat( sal_uIntPtr )
+void DdeData::SetFormat( sal_uLong )
{
}
-sal_uIntPtr DdeData::GetFormat() const
+sal_uLong DdeData::GetFormat() const
{
return 0L;
}
@@ -168,7 +168,7 @@ void DdeTopic::RemoveItem( const DdeItem& )
{
}
-DdeData* DdeTopic::Get( sal_uIntPtr )
+DdeData* DdeTopic::Get( sal_uLong )
{
return NULL;
}
@@ -246,7 +246,7 @@ String DdeService::GetHelp()
return String::EmptyString();
}
-void DdeService::AddFormat( sal_uIntPtr )
+void DdeService::AddFormat( sal_uLong )
{
}
@@ -305,7 +305,7 @@ DdeItem( rItem )
{
}
-DdeData* DdeGetPutItem::Get( sal_uIntPtr )
+DdeData* DdeGetPutItem::Get( sal_uLong )
{
return NULL;
}
diff --git a/svl/source/items/poolio.cxx b/svl/source/items/poolio.cxx
index 62cb544fa04d..ec55ba09195c 100644
--- a/svl/source/items/poolio.cxx
+++ b/svl/source/items/poolio.cxx
@@ -259,7 +259,7 @@ SvStream &SfxItemPool::Store(SvStream &rStream) const
#ifdef DBG_UTIL_MI
if ( !pItem->ISA(SfxSetItem) )
{
- sal_uIntPtr nMark = rStream.Tell();
+ sal_uLong nMark = rStream.Tell();
rStream.Seek( nItemStartPos + sizeof(sal_uInt16) );
SfxPoolItem *pClone = pItem->Create(rStream, nItemVersion );
sal_uInt16 nWh = pItem->Which();
@@ -390,7 +390,7 @@ void SfxItemPool::readTheItems (
SfxPoolItemArray_Impl *pNewArr = new SfxPoolItemArray_Impl();
SfxPoolItem *pItem = 0;
- sal_uIntPtr n, nLastSurrogate = sal_uIntPtr(-1);
+ sal_uLong n, nLastSurrogate = sal_uLong(-1);
while (aItemsRec.GetContent())
{
// n"achstes Surrogat holen
@@ -660,7 +660,7 @@ SvStream &SfxItemPool::Load(SvStream &rStream)
if ( !bSecondaryLoaded && pSecondary && pImp->bInSetItem )
{
// an das Ende des eigenen Pools seeken
- sal_uIntPtr nLastPos = rStream.Tell();
+ sal_uLong nLastPos = rStream.Tell();
aPoolRec.Skip();
// Sekund"arpool einlesen
@@ -769,20 +769,20 @@ SvStream &SfxItemPool::Load1_Impl(SvStream &rStream)
rStream >> nAttribSize;
// Size-Table einlesen
- sal_uIntPtr nStartPos = rStream.Tell();
+ sal_uLong nStartPos = rStream.Tell();
rStream.SeekRel( nAttribSize );
CHECK_FILEFORMAT( rStream, SFX_ITEMPOOL_TAG_SIZES );
sal_uInt32 nSizeTableLen;
rStream >> nSizeTableLen;
sal_Char *pBuf = new sal_Char[nSizeTableLen];
rStream.Read( pBuf, nSizeTableLen );
- sal_uIntPtr nEndOfSizes = rStream.Tell();
+ sal_uLong nEndOfSizes = rStream.Tell();
SvMemoryStream aSizeTable( pBuf, nSizeTableLen, STREAM_READ );
// ab Version 1.3 steht in der Size-Table eine Versions-Map
if ( pImp->nMajorVer > 1 || pImp->nMinorVer >= 3 )
{
// Version-Map finden (letztes sal_uIntPtr der Size-Table gibt Pos an)
rStream.Seek( nEndOfSizes - sizeof(sal_uInt32) );
sal_uInt32 nVersionMapPos;
rStream >> nVersionMapPos;
@@ -855,7 +855,7 @@ SvStream &SfxItemPool::Load1_Impl(SvStream &rStream)
}
// Position vor ersten Item merken
- sal_uIntPtr nLastPos = rStream.Tell();
+ sal_uLong nLastPos = rStream.Tell();
// SfxSetItems k"onnten Items aus Sekund"arpools beinhalten
if ( !bSecondaryLoaded && pSecondary && pDefItem->ISA(SfxSetItem) )
@@ -877,7 +877,7 @@ SvStream &SfxItemPool::Load1_Impl(SvStream &rStream)
// Items an sich lesen
for ( sal_uInt16 j = 0; j < nCount; ++j )
{
- sal_uIntPtr nPos = nLastPos;
+ sal_uLong nPos = nLastPos;
rStream >> nRef;
if ( bKnownItem )
@@ -969,7 +969,7 @@ SvStream &SfxItemPool::Load1_Impl(SvStream &rStream)
if ( pImp->nMajorVer > 1 || pImp->nMinorVer > 0 )
CHECK_FILEFORMAT( rStream, SFX_ITEMPOOL_TAG_DEFAULTS );
- sal_uIntPtr nLastPos = rStream.Tell();
+ sal_uLong nLastPos = rStream.Tell();
while ( rStream >> nWhich, nWhich )
{
// ggf. Which-Id aus alter Version verschieben?
@@ -980,7 +980,7 @@ SvStream &SfxItemPool::Load1_Impl(SvStream &rStream)
sal_uInt16 nMappedWhich = GetWhich(nSlot, sal_False);
int bKnownItem = bOwnPool || IsWhich(nMappedWhich);
- sal_uIntPtr nPos = nLastPos;
+ sal_uLong nPos = nLastPos;
sal_uInt32 nSize;
sal_uInt16 nVersion;
rStream >> nVersion;
@@ -1570,7 +1570,7 @@ FASTBOOL SfxItemPool::StoreItem( SvStream &rStream, const SfxPoolItem &rItem,
optional (falls 'bDirect == sal_True' oder '!rItem.IsPoolable()':
sal_uInt16 rItem.GetVersion()
- sal_uIntPtr Size
+ sal_uLong Size
Size rItem.Store()
@@ -1602,9 +1602,9 @@ FASTBOOL SfxItemPool::StoreItem( SvStream &rStream, const SfxPoolItem &rItem,
{
rStream << nItemVersion;
rStream << (sal_uInt32) 0L; // Platz fuer Laenge in Bytes
- sal_uIntPtr nIStart = rStream.Tell();
+ sal_uLong nIStart = rStream.Tell();
rItem.Store(rStream, nItemVersion);
- sal_uIntPtr nIEnd = rStream.Tell();
+ sal_uLong nIEnd = rStream.Tell();
rStream.Seek( nIStart-4 );
rStream << (sal_Int32) ( nIEnd-nIStart );
rStream.Seek( nIEnd );
@@ -1679,7 +1679,7 @@ const SfxPoolItem* SfxItemPool::LoadItem( SvStream &rStream, FASTBOOL bDirect,
sal_uInt16 nVersion;
sal_uInt32 nLen;
rStream >> nVersion >> nLen;
- sal_uIntPtr nIStart = rStream.Tell();
+ sal_uLong nIStart = rStream.Tell();
// Which-Id in dieser Version bekannt?
if ( nWhich )
@@ -1697,7 +1697,7 @@ const SfxPoolItem* SfxItemPool::LoadItem( SvStream &rStream, FASTBOOL bDirect,
}
else
pItem = 0;
- sal_uIntPtr nIEnd = rStream.Tell();
+ sal_uLong nIEnd = rStream.Tell();
DBG_ASSERT( nIEnd <= (nIStart+nLen), "read past end of item" );
if ( (nIStart+nLen) != nIEnd )
rStream.Seek( nIStart+nLen );
@@ -769,20 +769,20 @@ SvStream &SfxItemPool::Load1_Impl(SvStream &rStream)
if ( pImp->nMajorVer > 1 || pImp->nMinorVer >= 3 )
{
- // Version-Map finden (letztes sal_uIntPtr der Size-Table gibt Pos an)
+ // Version-Map finden (letztes sal_uLong der Size-Table gibt Pos an)
rStream.Seek( nEndOfSizes - sizeof(sal_uInt32) );
sal_uInt32 nVersionMapPos;